@@ -12,10 +12,10 @@ import requests
 from .models import MAX_ROWS_PER_PAGE
 
 
-def _random_pause(min_wait_seconds=0.5, max_wait_seconds=3):
-    """pause for min_wait_seconds up to max_wait_seconds"""
-    seconds = random.randrange(0.5, max_wait_seconds, 0.5)
-    time.sleep(seconds)
+def _random_pause():
+    """sleep for at least .333 seconds"""
+    seconds = random.randrange(3, 10, 1)
+    time.sleep(seconds / 10)
 
 
 def _url(*, route: str, slug: str = None) -> str:
@@ -201,7 +201,7 @@ def get(
         app_id (str): [description]
         api_key (str, optional): [description]. Defaults to None.
         slug (str, optional): Your organization's slug (aka, subdomain). As found in
-            your app metadata under accounts/slug.
+            your app metadata under accounts.slug.
         obj (str, optional): [description]. Defaults to None.
         scene (str, optional): [description]. Defaults to None.
         view (str, optional): [description]. Defaults to None.
@@ -337,7 +337,7 @@ def upload(
         api_key (str): [Knack API key](https://www.knack.com/developer-documentation/#find-your-api-key-amp-application-id).
         obj (str): The Knack object key which holds the record data.
         field (str): The knack field key of the field you're uploading into.
-        path: (str): The path to the file to be uploaded.
+        path (str): The path to the file to be uploaded.
         asset_type (str): The type of Knack field you're uploading to. Must be `file` or
             `image`.
         record_id (str, optional): The knack record ID to which the upload will be
